Okta SDK Python
===============

A Python library for the Okta Management APIs.

Getting Started
---------------
``` $ pip install okta ```

What you need
--------------------

- An Okta account, called an _organization_ (sign up for a free developer organization if you need one)
- [An API token](https://developer.okta.com/docs/api/getting_started/getting_a_token)

Look for our quickstart guide here!
- https://github.com/okta/okta-sdk-python

Okta Developer Forum
--------------------

Find out more and look for help here: https://devforum.okta.com/